@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: define.php 15938 2011-10-25 13:17:42Z moyo $
+ * @version $Id: define.php 17459 2012-02-09 20:17:17Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,13 +23,12 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
 */
 
 // Current version of GLPI
-define("GLPI_VERSION","0.80.5");
+define("GLPI_VERSION","0.80.7");
 define("GLPI_DEMO_MODE","0");
 
 
