@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: computer.form.php 15453 2011-08-22 10:12:56Z yllen $
+ * @version $Id: computer.form.php 17306 2012-01-31 13:09:59Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -109,12 +108,14 @@ if (isset($_POST["add"])) {
    glpi_header($_SERVER['HTTP_REFERER']);
 
 // Connect a computer to a printer/monitor/phone/peripheral
-} else if (isset($_POST["connect"]) && isset($_POST["items_id"]) && $_POST["items_id"]>0) {
-   $conn = new Computer_Item();
-   $conn->check(-1, 'w', $_POST);
-   $conn->add($_POST);
-   Event::log($_POST["computers_id"], "computers", 5, "inventory",
-              $_SESSION["glpiname"] ." ".$LANG['log'][27]);
+} else if (isset($_POST["connect"])) {
+   if (isset($_POST["items_id"]) && $_POST["items_id"]>0) {
+      $conn = new Computer_Item();
+      $conn->check(-1, 'w', $_POST);
+      $conn->add($_POST);
+      Event::log($_POST["computers_id"], "computers", 5, "inventory",
+                 $_SESSION["glpiname"] ." ".$LANG['log'][27]);
+   }
    glpi_header($_SERVER['HTTP_REFERER']);
 
 } else if (isset($_POST["unlock_monitor"])) {
