@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: massiveaction.php 15844 2011-10-10 08:35:08Z yllen $
+ * @version $Id: massiveaction.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -701,11 +700,11 @@ if (isset($_POST["itemtype"])) {
                      $input = addslashes_deep($input);
                      // Import new
                      $newid = $item->import($input);
-
+                     // delete with purge for dropwn with trash (Budget)
                      // Delete old
                      if ($newid > 0) {
                         $item->delete(array('id'          => $key,
-                                            '_replace_by' => $newid));
+                                            '_replace_by' => $newid), 1);
                      }
                   }
                }
