@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: popup.php 14684 2011-06-11 06:32:40Z remi $
+ * @version $Id: popup.php 17457 2012-02-09 15:26:40Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -92,11 +91,6 @@ if (isset($_SESSION["glpipopup"]["name"])) {
          include "ldap.import.php";
          break;
 
-      case "add_ruleparameter" :
-         popHeader($LANG['ldap'][35], $_SERVER['PHP_SELF']);
-         include strtolower($_GET['sub_type']."Parameter.php");
-         break;
-
       case "list_notificationtags" :
          popHeader($LANG['mailing'][138], $_SERVER['PHP_SELF']);
          include "notification.tags.php";
@@ -107,7 +101,6 @@ if (isset($_SESSION["glpipopup"]["name"])) {
          $kb = new KnowbaseItem;
          $kb->check($_GET["id"],'r');
          $kb->showFull(true);
-         popHeader($LANG['mailing'][138], $_SERVER['PHP_SELF']);
          break;
    }
    echo "<div class='center'><br><a href='javascript:window.close()'>".$LANG['buttons'][60]."</a>";
@@ -115,4 +108,4 @@ if (isset($_SESSION["glpipopup"]["name"])) {
    popFooter();
 }
 
-?>
\ No newline at end of file
+?>
