@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: reservation.form.php 14684 2011-06-11 06:32:40Z remi $
+ * @version $Id: reservation.form.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -91,8 +90,9 @@ if (isset($_POST["update"])) {
 
       $_POST['_ok'] = true;
       for ($i=0 ; $i<$times && ($_POST['_ok']) ; $i++) {
-         $_POST["begin"] = date('Y-m-d H:i:s', strtotime($begin)+$i*$to_add*DAY_TIMESTAMP);
-         $_POST["end"] = date('Y-m-d H:i:s', strtotime($end)+$i*$to_add*DAY_TIMESTAMP);
+      
+         $_POST["begin"]  = date('Y-m-d H:i:s', strtotime($begin." +".($i*$to_add)." day"));
+         $_POST["end"]  = date('Y-m-d H:i:s', strtotime($end." +".($i*$to_add)." day"));   
 
          if (haveRight("reservation_central","w")
              || getLoginUserID() === $_POST["users_id"]) {
@@ -116,6 +116,8 @@ if (isset($_POST["update"])) {
       // Only one reservation
       if (count($_POST['items']) == 1) {
          $toadd = "?reservationitems_id=$reservationitems_id";
+         $toadd .= "&mois_courant=".$_GET["mois_courant"];
+         $toadd .= "&annee_courante=".$_GET["annee_courant"];
       }
       glpi_header($CFG_GLPI["root_doc"] . "/front/reservation.php$toadd");
    }
