@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: stat.graph.php 14684 2011-06-11 06:32:40Z remi $
+ * @version $Id: stat.graph.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -197,7 +196,7 @@ switch($_GET["type"]) {
       $next  = $prev = 0;
       $next  = getNextItem("glpi_ticketsolutiontypes", $_GET["id"]);
       $prev  = getPreviousItem("glpi_ticketsolutiontypes", $_GET["id"]);
-      $title = $LANG['users'][1]."&nbsp;: ".Dropdown::getDropdownName("glpi_ticketsolutiontypes",
+      $title = $LANG['job'][48]."&nbsp;: ".Dropdown::getDropdownName("glpi_ticketsolutiontypes",
                                                                       $_GET["id"]);
       break;
 
