@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: common.function.php 15517 2011-08-29 07:54:35Z yllen $
+ * @version $Id: common.function.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -1203,13 +1202,13 @@ function formatNumber($number, $edit=false, $forcedecimal=-1) {
    // Display : clean display
    switch ($_SESSION['glpinumber_format']) {
       case 2 : // Other French
-         return str_replace(' ', '&nbsp;', number_format($number, $decimal, ', ', ' '));
+         return str_replace(' ', '&nbsp;', number_format($number, $decimal, ',', ' '));
 
       case 0 : // French
          return str_replace(' ', '&nbsp;', number_format($number, $decimal, '.', ' '));
 
       default: // English
-         return number_format($number, $decimal, '.', ', ');
+         return number_format($number, $decimal, '.', ',');
    }
 }
 
