@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: commondbtm.class.php 15774 2011-09-27 06:50:43Z moyo $
+ * @version $Id: commondbtm.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -2426,6 +2425,16 @@ class CommonDBTM extends CommonGLPI {
             $searchOption = $this->getSearchOptionByField('field', $key);
 
             if (isset($searchOption['datatype'])
+                && (is_null($value) || $value == '' ||  $value == 'NULL')) {
+
+               switch ($searchOption['datatype']) {
+                  case 'date' :
+                  case 'datetime' :
+                     // don't use $unset', because this is not a failure
+                     $this->input[$key] = 'NULL';
+                     break;
+               }
+            } else if (isset($searchOption['datatype'])
                 && !is_null($value)
                 && $value != ''
                 && $value != 'NULL') {
@@ -2616,7 +2625,12 @@ class CommonDBTM extends CommonGLPI {
             $p[$key] = $value;
          }
       }
-
+      
+      // Do not check for template
+      if (isset($this->input['is_template']) && $this->input['is_template']) { 
+         return true;
+      }
+      
       $result = true;
 
       //Do not check unicity when creating infocoms or if checking is expliclty disabled
