@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: computer_device.class.php 14684 2011-06-11 06:32:40Z remi $
+ * @version $Id: computer_device.class.php 17448 2012-02-08 09:52:32Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -239,7 +238,7 @@ class Computer_Device extends CommonDBTM {
             if ($device->getFromDB($data[$fk])) {
                echo "<tr class='tab_bg_2'>";
                echo "<td class='center'>";
-               Dropdown::showInteger("quantity_".$itemtype."_".$data['id'], $data['NB']);
+               Dropdown::showInteger("quantity_".$itemtype."_".$data['id'], $data['NB'],0,300);
                echo "</td><td>";
                if ($device->canCreate()) {
                   echo "<a href='".$device->getSearchURL()."'>".$device->getTypeName()."</a>";
@@ -533,8 +532,19 @@ class Computer_Device extends CommonDBTM {
          }
       }
 
-      if (isset($this->fields['specificity'])
-          && $this->fields['specificity'] == $this->input['specificity']) {
+      if ($input['_itemtype'] != 'DeviceMemory' 
+            && isset($this->fields['specificity'])
+               && $this->fields['specificity'] == $this->input['specificity']) {
+         // No change
+         return false;
+      }
+
+      //For memories, type can change even if specificity not
+      if ($input['_itemtype'] == 'DeviceMemory' 
+            && (isset($this->fields['specificity'])
+               && $this->fields['specificity'] == $this->input['specificity']) 
+                  && ((isset($this->fields['devicememories_id'])
+                      && (!isset($this->input['devicememories_id']) || $this->fields['devicememories_id'] == $this->input['devicememories_id'])))) {
          // No change
          return false;
       }
@@ -589,4 +599,4 @@ class Computer_Device extends CommonDBTM {
 
 
 }
-?>
\ No newline at end of file
+?>
