@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: contract.class.php 15081 2011-07-28 10:48:27Z moyo $
+ * @version $Id: contract.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -826,7 +825,9 @@ class Contract extends CommonDBTM {
       echo "<th>".$LANG['entity'][0]."</th>";
       echo "<th>".$LANG['common'][16]."</th>";
       echo "<th>".$LANG['common'][19]."</th>";
-      echo "<th>".$LANG['common'][20]."</th></tr>";
+      echo "<th>".$LANG['common'][20]."</th>";
+      echo "<th>".$LANG['state'][0]."</th>";      
+      echo "</tr>";
 
       $totalnb = 0;
       for ($i=0 ; $i<$number ; $i++) {
@@ -904,7 +905,13 @@ class Contract extends CommonDBTM {
                          (isset($data["serial"])? "".$data["serial"]."" :"-")."</td>";
                   echo "<td class='center'>".
                          (isset($data["otherserial"])? "".$data["otherserial"]."" :"-")."</td>";
-                  echo "</tr>";
+                  echo "<td class='center'>";
+                  if (isset($data["states_id"])) {
+                     echo Dropdown::getDropdownName("glpi_states",$data['states_id']);
+                  } else {
+                     echo '&nbsp;';
+                  }                         
+                  echo "</td></tr>";
                }
             }
             $totalnb += $nb;
