@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: document.class.php 15824 2011-10-03 08:20:40Z remi $
+ * @version $Id: document.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -1206,7 +1205,11 @@ class Document extends CommonDBTM {
          $linkparam = "&amp;tickets_id=".$item->fields['id'];
       }
 
-      $canedit = $item->can($ID,'w');
+      if ($item->getType() == 'Ticket' && $item->getField('status') == 'closed') {
+         $canedit = false;
+      } else {
+         $canedit = $item->can($ID,'w');
+      }
 
       $is_recursive=$item->isRecursive();
 
