@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: dropdown.class.php 15573 2011-09-01 10:10:06Z moyo $
+ * @version $Id: dropdown.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -71,7 +70,7 @@ class Dropdown {
       $table = $item->getTable();
 
       $params['name']        = $item->getForeignKeyField();
-      $params['value']       = '';
+      $params['value']       = ($itemtype=='Entity' ? $_SESSION['glpiactive_entity'] : '');
       $params['comments']    = true;
       $params['entity']      = -1;
       $params['entity_sons'] = false;
@@ -1380,7 +1379,7 @@ class Dropdown {
 
                case 'Ticket' :
                   $tmp = new TicketFollowup();
-                  if ($tmp->canCreate()) {
+                  if ($tmp->canCreate() && $_SESSION['glpiactiveprofile']['interface'] == 'central') {
                      echo "<option value='add_followup'>".$LANG['job'][29]."</option>";
                   }
 
@@ -1424,7 +1423,7 @@ class Dropdown {
                 && ($item instanceof CommonDropdown)
                 && $item->maybeRecursive()) {
 
-               if ($isadmin) {
+               if ($isadmin && (count($_SESSION['glpiactiveentities'])>1)) {
                   echo "<option value='merge'>".$LANG['buttons'][48]." - ".$LANG['software'][48];
                   echo "</option>";
                }
