@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: entity.class.php 15051 2011-07-27 12:25:49Z remi $
+ * @version $Id: entity.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -158,6 +157,7 @@ class Entity extends CommonTreeDropdown {
                   $mailcollector = new RuleMailCollector();
                   $mailcollector->showAndAddRuleForm($this);
                }
+               EntityData::showAdvancedOptions($this);
                Document::showAssociated($this);
                EntityData::showNotificationOptions($this);
                EntityData::showHelpdeskOptions($this);
@@ -444,6 +444,12 @@ class Entity extends CommonTreeDropdown {
       $tab[20]['joinparams']    = array('jointype' => 'child');
       $tab[20]['datatype']      = 'string';
 
+      $tab[25]['table']         = 'glpi_entitydatas';
+      $tab[25]['field']         = 'postcode';
+      $tab[25]['name']          = $LANG['financial'][100];
+      $tab[25]['joinparams']    = array('jointype' => 'child');
+      $tab[25]['datatype']      = 'string';
+
       return $tab;
    }
 
