@@ -1,10 +1,10 @@
 <?php
 
 /*
- * @version $Id: log.class.php 14982 2011-07-21 09:41:15Z remi $
+ * @version $Id: log.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -24,8 +24,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -172,7 +171,8 @@ class Log extends CommonDBTM {
 //                      }
 
                      // other cases ; link field -> get data from dropdown
-                     if ($val2["table"] != 'glpi_complete_entities') {
+                     if ($val2["table"] != 'glpi_complete_entities' 
+                        && $val2["table"] != 'glpi_auth_tables' ) {
                         $changes = array($id_search_option,
                                          addslashes(Dropdown::getDropdownName($val2["table"],
                                                                               $oldval)),
