@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: mailcollector.class.php 15420 2011-08-17 11:18:18Z moyo $
+ * @version $Id: mailcollector.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -523,7 +522,7 @@ class MailCollector  extends CommonDBTM {
       $glpi_message_match = "/GLPI-([0-9]+)\.[0-9]+\.[0-9]+@\w*/";
 
       // Check if email not send by GLPI : if yes -> blacklist
-      if (preg_match($glpi_message_match, $head['message_id'], $match)) {
+      if (!isset($head['message_id']) || preg_match($glpi_message_match, $head['message_id'], $match)) {
          $tkt['_blacklisted'] = true;
          return $tkt;
       }
@@ -781,7 +780,7 @@ class MailCollector  extends CommonDBTM {
     ///Connect To the Mail Box
    function connect() {
       $this->marubox = @imap_open($this->fields['host'], $this->fields['login'],
-                                  decrypt($this->fields['passwd'],GLPIKEY), 1);
+                                  decrypt($this->fields['passwd'],GLPIKEY), CL_EXPUNGE);
    }
 
 
