@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: notificationtargetticket.class.php 14908 2011-07-12 14:39:24Z moyo $
+ * @version $Id: notificationtargetticket.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -46,21 +45,23 @@ class NotificationTargetTicket extends NotificationTarget {
       $this->options['sendprivate']=false;
 
       if (isset($options['followup_id'])) {
-         $fup = new TicketFollowup();
+         $this->options['sendprivate'] = $options['is_private'];
+/*         $fup = new TicketFollowup();
          if ($fup->getFromDB($options['followup_id'])) {
             if ($fup->fields['is_private']) {
                $this->options['sendprivate'] = true;
             }
-         }
+         }*/
       }
 
       if (isset($options['task_id'])) {
-         $fup = new TicketTask();
+         $this->options['sendprivate'] = $options['is_private'];
+/*         $fup = new TicketTask();
          if ($fup->getFromDB($options['task_id'])) {
             if ($fup->fields['is_private']) {
                $this->options['sendprivate'] = true;
             }
-         }
+         }*/
       }
    }
 
@@ -832,7 +833,7 @@ class NotificationTargetTicket extends NotificationTarget {
 
          if ($this->obj->countGroups(Ticket::REQUESTER)) {
             $groups = array();
-            foreach ($this->obj->getUsers(Ticket::REQUESTER) as $gid => $tmp) {
+            foreach ($this->obj->getGroups(Ticket::REQUESTER) as $gid => $tmp) {
                $groups[$gid] = Dropdown::getDropdownName('glpi_groups', $gid);
             }
             $this->datas['##ticket.groups##'] = implode(', ',$groups);
@@ -1143,6 +1144,9 @@ class NotificationTargetTicket extends NotificationTarget {
                $tmp['##ticket.time##']             = Ticket::getActionTime($ticket['actiontime']);
                $tmp['##ticket.costtime##']         = $ticket['cost_time'];
                $tmp['##ticket.creationdate##']     = convDateTime($ticket['date']);
+               $tmp['##ticket.closedate##']        = convDateTime($ticket['closedate']);
+               $tmp['##ticket.solvedate##']        = convDateTime($ticket['solvedate']);
+               $tmp['##ticket.duedate##']          = convDateTime($ticket['due_date']);
                $tmp['##ticket.content##']          = $ticket['content'];
 
 
@@ -1224,7 +1228,7 @@ class NotificationTargetTicket extends NotificationTarget {
 
                if ($t->countUsers(Ticket::OBSERVER)) {
                   $users = array();
-                  foreach ($t->getUsers(Ticket::OBSERVER) as $uid => $tmp) {
+                  foreach ($t->getUsers(Ticket::OBSERVER) as $uid => $val) {
                      $user_tmp = new User();
                      $user_tmp->getFromDB($uid);
                      $users[$uid] = $user_tmp->getName();
@@ -1236,7 +1240,7 @@ class NotificationTargetTicket extends NotificationTarget {
 
                if ($t->countGroups(Ticket::OBSERVER)) {
                   $groups = array();
-                  foreach ($t->getGroups(Ticket::OBSERVER) as $gid => $tmp) {
+                  foreach ($t->getGroups(Ticket::OBSERVER) as $gid => $val) {
                      $groups[$gid] = Dropdown::getDropdownName('glpi_groups', $gid);
                   }
                   $tmp['##ticket.observergroups##'] = implode(', ',$groups);
