@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: profile_user.class.php 14684 2011-06-11 06:32:40Z remi $
+ * @version $Id: profile_user.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -113,7 +112,8 @@ class Profile_User extends CommonDBTM {
 
          echo "<tr class='tab_bg_2'><td class='center'>";
          echo "<input type='hidden' name='users_id' value='$ID'>";
-         Dropdown::show('Entity', array('entity' => $_SESSION['glpiactiveentities']));
+         Dropdown::show('Entity', array('entity' => $_SESSION['glpiactiveentities'],
+                                        'value'  => $_SESSION['glpiactive_entity']));
          echo "</td><td class='center'>".$LANG['profiles'][22]."&nbsp;: ";
          Profile::dropdownUnder(array('value' => Profile::getDefault()));
          echo "</td><td class='center'>".$LANG['profiles'][28]."&nbsp;: ";
@@ -577,17 +577,23 @@ class Profile_User extends CommonDBTM {
    }
 
 
-   static function getEntitiesForProfileByUser($users_id, $profiles_id) {
+   static function getEntitiesForProfileByUser($users_id, $profiles_id, $child=false) {
       global $DB;
 
-      $query = "SELECT `entities_id`
+      $query = "SELECT `entities_id`, `is_recursive`
                 FROM `glpi_profiles_users`
                 WHERE `users_id` = '$users_id'
                       AND `profiles_id` = '$profiles_id'";
 
       $entities = array();
       foreach ($DB->request($query) as $data) {
-         $entities[$data['entities_id']] = $data['entities_id'];
+         if ($child && $data['is_recursive']) {
+            foreach (getSonsOf('glpi_entities', $data['entities_id']) as $id) {
+               $entities[$id] = $id;
+            }
+         } else {
+            $entities[$data['entities_id']] = $data['entities_id'];
+         }
       }
       return $entities;
    }
