@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: rule.class.php 15921 2011-10-25 08:00:25Z moyo $
+ * @version $Id: rule.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -1042,18 +1041,21 @@ class Rule extends CommonDBTM {
          echo "<td>&nbsp;</td>";
       }
 
-      echo "<td><a id='rules".$this->fields["id"]."' href=\"".str_replace(".php",".form.php",$target).
-                 "?id=".$this->fields["id"]."&amp;onglet=1\">" . $this->fields["name"] . "</a> ";
+      echo "<td>".$this->getLink()."&nbsp;";
 
       if (!empty($this->fields["comment"])) {
-         showToolTip($this->fields["comment"], array('applyto' => "rules".$this->fields["id"]));
+         showToolTip($this->fields["comment"]);
       }
       echo "</td>";
       echo "<td>".$this->fields["description"]."</td>";
       echo "<td>".Dropdown::getYesNo($this->fields["is_active"])."</td>";
 
       if ($display_entities) {
-         echo "<td>".Dropdown::getDropdownName('glpi_entities', $this->fields['entities_id'])."</td>";
+         $rec = '';
+         if ($this->maybeRecursive() && $this->fields['is_recursive']) {
+            $rec =' <b>(R)</b>';
+         }
+         echo "<td>".Dropdown::getDropdownName('glpi_entities', $this->fields['entities_id'])."$rec</td>";
       }
 
       if (!$display_entities) {
