@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: rulemailcollector.class.php 14943 2011-07-18 13:07:56Z moyo $
+ * @version $Id: rulemailcollector.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -258,6 +257,7 @@ class RuleMailCollector extends Rule {
                         if ($profile) {
                            $entities = array();
                            if (isset($params['_users_id_requester'])) { // Not set when testing
+                              // Retrieve only the "top" entities
                               $entities = Profile_User::getEntitiesForProfileByUser($params['_users_id_requester'],
                                                                                     $profile);
                            }
@@ -279,9 +279,16 @@ class RuleMailCollector extends Rule {
                                     $user = new User;
                                     $user->getFromDB($params['_users_id_requester']);
 
-                                    //If an entity is defined in user's preferences, use this one
-                                    //else do not set the rule as matched
-                                    if (is_integer($user->getField('entities_id'))) {
+                                    $tmpid = $user->getField('entities_id');
+
+                                    // Retrieve all the entities (pref could be set on a child)
+                                    $entities = Profile_User::getEntitiesForProfileByUser($params['_users_id_requester'],
+                                                                                          $profile, true);
+
+                                    // If an entity is defined in user's preferences,
+                                    // and this entity allowed for this profile, use this one
+                                    // else do not set the rule as matched
+                                    if (in_array($tmpid, $entities)) {
                                        $output['entities_id'] = $user->fields['entities_id'];
                                     }
                                  }
