@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: ticketfollowup.class.php 14684 2011-06-11 06:32:40Z remi $
+ * @version $Id: ticketfollowup.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -196,7 +195,9 @@ class TicketFollowup  extends CommonDBTM {
       Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
                    HISTORY_DELETE_SUBITEM);
 
-      $options = array('followup_id' => $this->fields["id"]);
+      $options = array('followup_id' => $this->fields["id"], 
+                        // Force is_private with data / not available
+                        'is_private' => $this->fields['is_private']);
       NotificationEvent::raiseEvent('delete_followup', $job, $options);
    }
 
@@ -223,7 +224,8 @@ class TicketFollowup  extends CommonDBTM {
             if ($CFG_GLPI["use_mailing"]
                 && (in_array("content",$this->updates)
                     || isset($this->input['_need_send_mail']))) {
-               $options = array('followup_id' => $this->fields["id"]);
+               $options = array('followup_id' => $this->fields["id"],
+                                'is_private'  => $this->fields["is_private"]);
 
                NotificationEvent::raiseEvent("update_followup", $job, $options);
             }
@@ -341,7 +343,8 @@ class TicketFollowup  extends CommonDBTM {
       }
 
       if ($donotif) {
-         $options = array('followup_id' => $this->fields["id"]);
+         $options = array('followup_id' => $this->fields["id"],
+                          'is_private'  => $this->fields["is_private"]);
          NotificationEvent::raiseEvent("add_followup", $this->input["_job"], $options);
       }
 
