@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: tickettask.class.php 15707 2011-09-20 06:56:37Z moyo $
+ * @version $Id: tickettask.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -178,7 +177,9 @@ class TicketTask  extends CommonDBTM {
       Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
                    HISTORY_DELETE_SUBITEM);
 
-      $options = array('task_id' => $this->fields["id"]);
+      $options = array('task_id'     => $this->fields["id"], 
+                        // Force is_private with data / not available
+                        'is_private' => $this->fields['is_private']);
       NotificationEvent::raiseEvent('delete_task', $job, $options);
    }
 
@@ -209,14 +210,15 @@ class TicketTask  extends CommonDBTM {
       $job         = new Ticket;
       $mailsend    = false;
 
-      if ($job->getFromDB($this->input["tickets_id"])) {
-         $job->updateDateMod($this->input["tickets_id"]);
+      if ($job->getFromDB($this->fields["tickets_id"])) {
+         $job->updateDateMod($this->fields["tickets_id"]);
 
          if (count($this->updates)) {
             $update_done = true;
 
             if ($CFG_GLPI["use_mailing"] && (in_array("content",$this->updates))) {
-               $options = array('task_id' => $this->fields["id"]);
+               $options = array('task_id'    => $this->fields["id"],
+                                'is_private' => $this->fields['is_private']);
                NotificationEvent::raiseEvent('update_task', $job, $options);
                $mailsend = true;
             }
@@ -356,7 +358,8 @@ class TicketTask  extends CommonDBTM {
       }
 
       if ($donotif) {
-         $options = array('task_id' => $this->fields["id"]);
+         $options = array('task_id'    => $this->fields["id"],
+                          'is_private' => $this->fields['is_private']);
          NotificationEvent::raiseEvent('add_task', $this->input["_job"], $options);
       }
 
