@@ -2,10 +2,10 @@
 
 
 /*
- * @version $Id: user.class.php 15740 2011-09-22 11:02:07Z remi $
+ * @version $Id: user.class.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -25,8 +25,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
  --------------------------------------------------------------------------
  */
 
@@ -1071,7 +1070,9 @@ class User extends CommonDBTM {
       $listgroups = array();
 
       //User dn may contain ( or ), need to espace it!
-      $user_dn = str_replace(array("(", ")"), array("\(", "\)"), $user_dn);
+      //User dn may also contains \, which must be replaced by \\, ...
+      //$user_dn = addslashes($user_dn);
+      $user_dn = str_replace(array("(", ")", "\,", "\+"), array("\(", "\)", "\\\,", "\\\+"), $user_dn);
 
       //Only retrive cn and member attributes from groups
       $attrs = array('dn');
@@ -1088,6 +1089,7 @@ class User extends CommonDBTM {
 
       //Get the result of the search as an array
       $info = ldap_get_entries_clean($ds, $sr);
+
       //Browse all the groups
       for ($i = 0 ; $i < count($info) ; $i++) {
          //Get the cn of the group and add it to the list of groups
@@ -1615,10 +1617,10 @@ class User extends CommonDBTM {
          $result = $DB->query($query);
 
          if ($DB->numrows($result) > 0) {
+            /// To display a message
+            $this->fields['name'] = $this->oldvalues['name'];
             unset($this->updates[$key]);
             unset($this->oldvalues['name']);
-            /// For displayed message
-            $this->fields['name'] = $this->oldvalues['name'];
             addMessageAfterRedirect($LANG['setup'][614], false, ERROR);
          }
       }
@@ -1806,6 +1808,7 @@ class User extends CommonDBTM {
 
       $tab[23]['table']         = $this->getTable();
       $tab[23]['field']         = 'date_sync';
+      $tab[23]['datatype']      = 'datetime';
       $tab[23]['name']          = $LANG['login'][29];
       $tab[23]['massiveaction'] = false;
 
@@ -2227,7 +2230,8 @@ class User extends CommonDBTM {
                        `glpi_groups`.`name`
                 FROM `glpi_groups_users`
                 LEFT JOIN `glpi_groups` ON (`glpi_groups`.`id` = `glpi_groups_users`.`groups_id`)
-                WHERE `glpi_groups_users`.`users_id` = '$ID'";
+                WHERE `glpi_groups_users`.`users_id` = '$ID'
+                      AND `glpi_groups_users`.`groups_id` > 0";
       $result = $DB->query($query);
       $number = $DB->numrows($result);
 
@@ -2252,6 +2256,7 @@ class User extends CommonDBTM {
       echo "<th>".$LANG['common'][16]."</th>";
       echo "<th>".$LANG['common'][19]."</th>";
       echo "<th>".$LANG['common'][20]."</th>";
+      echo "<th>".$LANG['state'][0]."</th>";      
       echo "<th>&nbsp;</th></tr>";
 
       foreach ($CFG_GLPI["linkuser_types"] as $itemtype) {
@@ -2305,7 +2310,13 @@ class User extends CommonDBTM {
                   } else {
                      echo '&nbsp;';
                   }
-                  echo "<td class='center'>$linktype</td></tr>";
+                  echo "</td><td class='center'>";
+                  if (isset($data["states_id"])) {
+                     echo Dropdown::getDropdownName("glpi_states",$data['states_id']);
+                  } else {
+                     echo '&nbsp;';
+                  }                  
+                  echo "</td><td class='center'>$linktype</td></tr>";
                }
             }
          }
