@@ -1,3 +1,9 @@
+/*!
+ * Ext JS Library 3.4.0
+ * Copyright(c) 2006-2011 Sencha Inc.
+ * licensing@sencha.com
+ * http://www.sencha.com/license
+ */
 /**
  * Portuguese/Brazil Translation by Weber Souza
  * 08 April 2007
@@ -172,7 +178,8 @@ if(Ext.form.DateField){
       minText           : "A data deste campo deve ser posterior a {0}",
       maxText           : "A data deste campo deve ser anterior a {0}",
       invalidText       : "{0} n&atilde;o &eacute; uma data v&aacute;lida - deve ser informado no formato {1}",
-      format            : "d/m/Y"
+      format            : "d/m/Y",
+      startDay          : 0
    });
 }
 
@@ -185,7 +192,7 @@ if(Ext.form.ComboBox){
 
 if(Ext.form.VTypes){
    Ext.apply(Ext.form.VTypes, {
-      emailText    : 'Este campo deve ser um endere&ccedil;o de e-mail v&aacute;lido, no formado "usuario@dominio.com.br"',
+      emailText    : 'Este campo deve ser um endere&ccedil;o de e-mail v&aacute;lido, no formato "usuario@dominio.com.br"',
       urlText      : 'Este campo deve ser uma URL no formato "http:/'+'/www.dominio.com.br"',
       alphaText    : 'Este campo deve conter apenas letras e _',
       alphanumText : 'Este campo deve conter apenas letras, n&uacute;meros e _'
@@ -194,7 +201,7 @@ if(Ext.form.VTypes){
 
 if(Ext.form.HtmlEditor){
    Ext.apply(Ext.form.HtmlEditor.prototype, {
-        createLinkText : 'Porfavor, entre com a URL do link:',
+        createLinkText : 'Por favor, entre com a URL do link:',
         buttonTips : {
             bold : {
                title: 'Negrito (Ctrl+B)',
@@ -202,8 +209,8 @@ if(Ext.form.HtmlEditor){
                cls: 'x-html-editor-tip'
             },
             italic : {
-               title: 'Italico (Ctrl+I)',
-               text: 'Deixa o texto selecionado em italico.',
+               title: 'It&aacute;lico (Ctrl+I)',
+               text: 'Deixa o texto selecionado em it&aacute;lico.',
                cls: 'x-html-editor-tip'
             },
             underline : {
@@ -257,8 +264,8 @@ if(Ext.form.HtmlEditor){
                cls: 'x-html-editor-tip'
            },
            createlink : {
-               title: 'Hyperliga&ccedil;&atilde;o',
-               text: 'Transforma o texto selecionado em um hyperlink.',
+               title: 'Link',
+               text: 'Transforma o texto selecionado em um link.',
                cls: 'x-html-editor-tip'
            },
            sourceedit : {
