@@ -1,10 +1,10 @@
 <?php 
 /*
- * @version $Id: zh_CN.php 15737 2011-09-21 19:39:19Z moyo $ 
+ * @version $Id: zh_CN.php 17154 2012-01-24 11:27:36Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2011 by the INDEPNET Development Team.
- 
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
+
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
 
@@ -23,9 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- -------------------------------------------------------------------------
+ along with GLPI. If not, see <http://www.gnu.org/licenses/>.
+ --------------------------------------------------------------------------
  */
 //zh_CN
 
